@@ -7,9 +7,89 @@ from typing import Optional
 import click
 
 from .api_client import StudioManagerClient
+from .auth import get_aws_username
 from .progress import format_idle_state, format_time_ago, wait_with_progress
 
 
+def _update_ssh_config_silent(client: StudioManagerClient, env: str) -> bool:
+    """Update SSH config silently. Returns True if successful."""
+    ssh_config_path = os.path.expanduser("~/.ssh/config")
+
+    try:
+        # Read existing config
+        if os.path.exists(ssh_config_path):
+            with open(ssh_config_path, "r") as f:
+                lines = f.readlines()
+        else:
+            lines = []
+
+        # Remove managed entries
+        managed_start = "# BEGIN DAYHOFF ENGINES\n"
+        managed_end = "# END DAYHOFF ENGINES\n"
+
+        new_lines = []
+        skip = False
+        for line in lines:
+            if line == managed_start:
+                skip = True
+            elif line == managed_end:
+                skip = False
+                continue
+            elif not skip:
+                new_lines.append(line)
+
+        # Get engines
+        result = client.list_engines()
+        engines = result.get("engines", [])
+
+        if not engines:
+            return False
+
+        # Generate new entries
+        config_entries = [managed_start]
+
+        try:
+            current_user = get_aws_username()
+        except RuntimeError:
+            # Not authenticated - can't determine user, skip filtering
+            current_user = None
+
+        for engine in engines:
+            user = engine.get("user", "unknown")
+
+            # Skip engines owned by other users (unless user is unknown or we can't determine current user)
+            if current_user and user != "unknown" and user != current_user:
+                continue
+
+            instance_id = engine.get("instance_id")
+            name = engine.get("name", instance_id)
+            state = engine.get("state", "unknown")
+
+            # Only add running engines
+            if state != "running":
+                continue
+
+            config_entries.append(f"\nHost {name}\n")
+            config_entries.append(f"    HostName {instance_id}\n")
+            config_entries.append(f"    User {user}\n")
+            config_entries.append(
+                f"    ProxyCommand aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\n"
+            )
+
+        config_entries.append(managed_end)
+
+        # Write back
+        new_lines.extend(config_entries)
+
+        with open(ssh_config_path, "w") as f:
+            f.writelines(new_lines)
+
+        return True
+
+    except Exception:
+        return False
+
+
 @click.group()
 def engine_cli():
     """Manage engines."""
@@ -35,14 +115,27 @@ def engine_cli():
 @click.option(
     "--no-wait", is_flag=True, help="Return immediately without waiting for readiness"
 )
+@click.option(
+    "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
+)
 @click.option("--env", default="dev", help="Environment (dev, sand, prod)")
 def launch_engine(
-    name: str, engine_type: str, boot_disk_size: Optional[int], no_wait: bool, env: str
+    name: str,
+    engine_type: str,
+    boot_disk_size: Optional[int],
+    no_wait: bool,
+    skip_ssh_config: bool,
+    env: str,
 ):
     """Launch a new engine and wait for it to be ready."""
 
     client = StudioManagerClient(environment=env)
-    user = os.environ.get("USER") or os.environ.get("USERNAME", "unknown")
+
+    try:
+        user = get_aws_username()
+    except RuntimeError as e:
+        click.echo(f"✗ {e}", err=True)
+        raise click.Abort()
 
     click.echo(f"🚀 Launching {engine_type} engine '{name}'...")
 
@@ -64,7 +157,7 @@ def launch_engine(
         click.echo(f"\n⏳ Waiting for engine to be ready (typically 2-3 minutes)...\n")
 
         try:
-            final_status = wait_with_progress(
+            _final_status = wait_with_progress(
                 status_func=lambda: client.get_engine_readiness(engine_id),
                 is_complete_func=lambda s: s.get("ready", False),
                 label="Progress",
@@ -72,6 +165,12 @@ def launch_engine(
             )
 
             click.echo(f"\n✓ Engine ready!")
+
+            # Update SSH config unless skipped
+            if not skip_ssh_config:
+                if _update_ssh_config_silent(client, env):
+                    click.echo("✓ SSH config updated")
+
             click.echo(f"\nConnect with:")
             click.echo(f"  dh studio attach {name}")
             click.echo(f"  dh engine ssh {name}")
@@ -87,8 +186,14 @@ def launch_engine(
 
 @engine_cli.command("start")
 @click.argument("name_or_id")
+@click.option(
+    "--no-wait", is_flag=True, help="Return immediately without waiting for readiness"
+)
+@click.option(
+    "--skip-ssh-config", is_flag=True, help="Don't automatically update SSH config"
+)
 @click.option("--env", default="dev", help="Environment (dev, sand, prod)")
-def start_engine(name_or_id: str, env: str):
+def start_engine(name_or_id: str, no_wait: bool, skip_ssh_config: bool, env: str):
     """Start a stopped engine."""
 
     client = StudioManagerClient(environment=env)
@@ -112,6 +217,76 @@ def start_engine(name_or_id: str, env: str):
 
         click.echo(f"✓ Engine '{engine_name}' is starting")
 
+        if no_wait:
+            click.echo(f"\nCheck status with:")
+            click.echo(f"  dh engine status {engine_name}")
+            return
+
+        # Wait for engine to be running and fully ready (including status checks)
+        click.echo(f"\n⏳ Waiting for engine to be ready...\n")
+
+        try:
+
+            def check_engine_running():
+                """Check if engine is running, status checks passed, and SSM is accessible."""
+                # Check EC2 state and status checks
+                instance_status = client.check_instance_status(engine_id)
+                if "error" in instance_status:
+                    return {"ready": False, "progress_percent": 0}
+
+                state = instance_status.get("state", "unknown")
+                status_checks_passed = instance_status.get("reachable", False)
+
+                # Check SSM accessibility via idle state
+                engine_status = client.get_engine_status(engine_id)
+                ssm_working = (
+                    not ("error" in engine_status)
+                    and engine_status.get("idle_state") is not None
+                )
+
+                # Progress based on state and checks
+                if state == "pending":
+                    progress = 30
+                elif state == "running" and not status_checks_passed:
+                    # Running but status checks still initializing
+                    progress = 60
+                elif state == "running" and status_checks_passed and not ssm_working:
+                    # Status checks passed but SSM not yet responding
+                    progress = 85
+                elif state == "running" and status_checks_passed and ssm_working:
+                    # Fully ready
+                    progress = 100
+                else:
+                    progress = 10
+
+                # Ready when running AND status checks pass AND SSM works
+                ready = state == "running" and status_checks_passed and ssm_working
+
+                return {"ready": ready, "progress_percent": progress}
+
+            _final_status = wait_with_progress(
+                status_func=check_engine_running,
+                is_complete_func=lambda s: s.get("ready", False),
+                label="Starting",
+                timeout_seconds=300,
+                show_stages=False,
+            )
+
+            click.echo(f"\n✓ Engine ready!")
+
+            # Update SSH config unless skipped
+            if not skip_ssh_config:
+                if _update_ssh_config_silent(client, env):
+                    click.echo("✓ SSH config updated")
+
+            click.echo(f"\nConnect with:")
+            click.echo(f"  dh studio attach {engine_name}")
+            click.echo(f"  dh engine ssh {engine_name}")
+
+        except TimeoutError:
+            click.echo(f"\n⚠ Engine is still starting. Check status with:")
+            click.echo(f"  dh engine status {engine_name}")
+
     except Exception as e:
         click.echo(f"✗ Error: {e}", err=True)
         raise click.Abort()
@@ -362,27 +537,31 @@ def config_ssh(clean: bool, all: bool, admin: bool, env: str):
         # Generate new entries
         config_entries = [managed_start]
 
-        current_user = os.environ.get("USER", "unknown")
+        try:
+            current_user = get_aws_username()
+        except RuntimeError:
+            # Not authenticated - can't determine user
+            current_user = None
 
         for engine in engines:
-            owner = engine.get("owner", "unknown")
+            user = engine.get("user", "unknown")
 
-            # Skip if not all and not owned by current user
-            if not all and owner != current_user:
+            # Skip if not all and not owned by current user (unless user is unknown or we can't determine current user)
+            if not all and current_user and user != "unknown" and user != current_user:
                 continue
 
-            engine_id = engine.get("engine_id")
-            name = engine.get("name", engine_id)
+            instance_id = engine.get("instance_id")
+            name = engine.get("name", instance_id)
             state = engine.get("state", "unknown")
 
             # Only add running engines
             if state != "running":
                 continue
 
-            username = "ec2-user" if admin else owner
+            username = "ec2-user" if admin else user
 
             config_entries.append(f"\nHost {name}\n")
-            config_entries.append(f"    HostName {engine_id}\n")
+            config_entries.append(f"    HostName {instance_id}\n")
             config_entries.append(f"    User {username}\n")
             config_entries.append(
                 f"    ProxyCommand aws ssm start-session --target %h --document-name AWS-StartSSHSession --parameters 'portNumber=%p'\n"
