@@ -4,13 +4,14 @@ import sys
 from importlib.metadata import PackageNotFoundError, version
 
 import typer
-
 from dayhoff_tools.cli.cloud_commands import aws_app, gcp_app
-from dayhoff_tools.cli.engine import engine_app, studio_app
+from dayhoff_tools.cli.engine1 import engine_app, studio_app
 from dayhoff_tools.cli.utility_commands import (
+    add_dependency,
     build_and_upload_wheel,
     delete_local_branch,
-    install_dependencies,
+    remove_dependency,
+    sync_with_toml,
     test_github_actions_locally,
     update_dependencies,
 )
@@ -45,8 +46,13 @@ app.command("clean")(delete_local_branch)
 
 # Dependency Management
 app.command(
-    "install", help="Install dependencies based on pyproject.toml and sync environment."
-)(install_dependencies)
+    "tomlsync",
+    help="Sync environment with platform-specific TOML manifest (install/update dependencies).",
+)(sync_with_toml)
+app.command("add", help="Add a dependency to all platform manifests.")(add_dependency)
+app.command("remove", help="Remove a dependency from all platform manifests.")(
+    remove_dependency
+)
 app.command("update", help="Update dayhoff-tools (or all deps) and sync environment.")(
     update_dependencies
 )
@@ -62,11 +68,37 @@ app.command("wimport")(import_from_warehouse_typer)
 app.add_typer(gcp_app, name="gcp", help="Manage GCP authentication and impersonation.")
 app.add_typer(aws_app, name="aws", help="Manage AWS SSO authentication.")
 
-# Engine and Studio commands
+# Engine and Studio commands (original implementation)
 app.add_typer(engine_app, name="engine", help="Manage compute engines for development.")
 app.add_typer(studio_app, name="studio", help="Manage persistent development studios.")
 
 
+# Engine and Studio commands (new implementation with progress tracking)
+# These use Click instead of Typer, so we need a passthrough wrapper
+@app.command(
+    "engine2",
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
+)
+def engine2_cmd(ctx: typer.Context):
+    """Manage engines (new implementation with progress tracking)."""
+    from dayhoff_tools.cli.engines_studios import engine_cli
+
+    # Pass arguments directly to Click CLI
+    engine_cli(ctx.args, standalone_mode=False)
+
+
+@app.command(
+    "studio2",
+    context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
+)
+def studio2_cmd(ctx: typer.Context):
+    """Manage studios (new implementation with progress tracking)."""
+    from dayhoff_tools.cli.engines_studios import studio_cli
+
+    # Pass arguments directly to Click CLI
+    studio_cli(ctx.args, standalone_mode=False)
+
+
 @app.callback(invoke_without_command=True)
 def _version_option(
     ctx: typer.Context,
