@@ -614,6 +614,24 @@ def setup_rxnfp() -> None:
     )
 
 
+def clean_docker_config() -> None:
+    """Clean Docker configuration to avoid credential helper conflicts.
+
+    VS Code dev containers can set up credential helpers that interfere with
+    Docker builds and registry operations. This function creates a clean
+    configuration that disables problematic credential helpers.
+
+    This is automatically called before Docker builds and registry operations
+    to prevent authentication failures.
+    """
+    docker_config_dir = os.path.expanduser("~/.docker")
+    os.makedirs(docker_config_dir, exist_ok=True)
+
+    # Write a minimal config file that disables credential helpers
+    with open(os.path.join(docker_config_dir, "config.json"), "w") as f:
+        json.dump({"auths": {}, "credsStore": ""}, f)
+
+
 def docker_login(registry: str, username: str, password: str) -> None:
     """Login to a Docker registry using provided credentials.
 
@@ -625,13 +643,8 @@ def docker_login(registry: str, username: str, password: str) -> None:
     Raises:
         subprocess.CalledProcessError: If Docker login fails
     """
-    # Create .docker directory if it doesn't exist
-    docker_config_dir = os.path.expanduser("~/.docker")
-    os.makedirs(docker_config_dir, exist_ok=True)
-
-    # Write a minimal config file that disables credential helpers
-    with open(os.path.join(docker_config_dir, "config.json"), "w") as f:
-        json.dump({"auths": {}, "credsStore": ""}, f)
+    # Clean Docker config to avoid credential helper conflicts
+    clean_docker_config()
 
     # Login to Docker using the credentials
     login_process = subprocess.run(
